Task: IWSLT14
==============
Description: 2014 International Workshop on Spoken Language task, currently only includes en_de and de_en. From Cettolo et al. '12. Link: wit3.fbk.eu

Tags: #IWSLT14, #All, #MT, #decanlp

